@@ -21,6 +21,12 @@
 #define _BFTEXTVIEW2_LANGMGR_H_
 
 #include "bftextview2.h"
+typedef struct {
+	GList *stack; /* a list of context-id's (or "nameless-context") and group-id's (or "nameless-group"), etc., that has the most recent parsed on top, and the root context at the bottom */
+} Tlangdebug;
+
+gchar *ldb_stack_string(gpointer ldb);
+
 const gchar *lookup_user_option(const gchar * lang, const gchar * option);
 void langmgr_add_custom_mime(Tbflang *bflang, const gchar *mime);
 void langmgr_reload_user_options(void);
@@ -31,6 +37,7 @@ GtkTextTag *langmrg_lookup_tag_highlight(const gchar * lang, const gchar * highl
 GtkTextTagTable *langmgr_get_tagtable(void);
 Tbflang *langmgr_get_bflang(const gchar * mimetype, const gchar * filename);
 GList *langmgr_get_languages_mimetypes(void);
+gchar *langmgr_get_language_name_by_mimetype(gchar * mime);
 gboolean langmgr_in_highlight_tags(GtkTextTag * tag);
 #ifdef HAVE_LIBENCHANT
 GtkTextTag **langmgr_no_spellcheck_tags(void);
