@@ -1,7 +1,7 @@
 /* Bluefish HTML Editor
  * bftextview2_scanner.h
  *
- * Copyright (C) 2008-2011 Olivier Sessink
+ * Copyright (C) 2008-2015 Olivier Sessink
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,12 +29,13 @@ Tfound *get_foundcache_first(BluefishTextView * bt2, GSequenceIter ** retsiter);
 Tfound *get_foundcache_at_offset(BluefishTextView * btv, guint offset, GSequenceIter ** retsiter);
 void foundcache_update_offsets(BluefishTextView * btv, guint startpos, gint offset);
 Tfoundblock *pop_blocks(gint numchange, Tfoundblock * curblock);
+gboolean test_condition(Tfoundcontext *curfcontext, Tfoundblock *curfblock, Tpattern_condition *pcond);
 gboolean bftextview2_run_scanner(BluefishTextView * btv, GtkTextIter * visible_end);
 void scan_for_prefix_start(BluefishTextView * btv, guint16 contextnum, GtkTextIter * start,
 						   GtkTextIter * cursor);
 void scan_for_autocomp_prefix(BluefishTextView * btv, GtkTextIter * mstart, GtkTextIter * cursorpos,
-							  gint * contextnum);
-gboolean scan_for_tooltip(BluefishTextView * btv, GtkTextIter * mstart, GtkTextIter * position,
+						 gint * contextnum);
+guint scan_for_tooltip(BluefishTextView * btv, GtkTextIter * mstart, GtkTextIter * position,
 						  gint * contextnum);
 void cleanup_scanner(BluefishTextView * btv);
 void scancache_destroy(BluefishTextView * btv);
