@@ -826,7 +826,7 @@ doc_save_backend(Tdocument * doc, Tdocsave_mode savemode, gboolean close_doc,
 	DEBUG_MSG("doc_save_backend, calling file_checkNsave_uri_async with uri %p for %zd bytes\n", dest_uri, strlen(buffer->data));
 	doc->save =
 		file_checkNsave_uri_async(dest_uri, dest_finfo, buffer, numbytes, (savemode == docsave_normal && main_v->props.check_for_modified_on_disk!=0),
-								  main_v->props.backup_file, doc_checkNsave_lcb, dsb);
+								  main_v->props.backup_file, doc_checkNsave_lcb, dsb, doc->bfwin);
 
 	if (firstsave || savemode == docsave_saveas || savemode == docsave_move) {
 		if(doc->readonly) {
