@@ -336,9 +336,7 @@ htmlbar_insert_acronym_tag(GtkAction * action, gpointer user_data)
 static void
 htmlbar_insert_align_right_tag(GtkAction * action, gpointer user_data)
 {
-	doc_insert_two_strings(BFWIN(user_data)->current_document,
-						   get_curlang_option_value(BFWIN(user_data), lang_is_XHTML) ? cap("<DIV STYLE=\"text-align: right\">") : cap("<DIV ALIGN=\"RIGHT\">"),
-						   cap("</DIV>"));
+	doc_insert_two_strings(BFWIN(user_data)->current_document, cap("<DIV STYLE=\"text-align: right;\">"), cap("</DIV>"));
 }
 
 static void
@@ -369,9 +367,7 @@ htmlbar_insert_break_tag(GtkAction * action, gpointer user_data)
 static void
 htmlbar_insert_center_tag(GtkAction * action, gpointer user_data)
 {
-	doc_insert_two_strings(BFWIN(user_data)->current_document,
-						   get_curlang_option_value(BFWIN(user_data), lang_is_XHTML) ? cap("<DIV STYLE=\"text-align: center\">") : cap("<DIV ALIGN=\"CENTER\">"),
-						   cap("</DIV>"));
+	doc_insert_two_strings(BFWIN(user_data)->current_document, cap("<DIV STYLE=\"text-align: center;\">"), cap("</DIV>"));
 }
 
 static void
@@ -440,17 +436,13 @@ htmlbar_insert_emphasis_tag(GtkAction * action, gpointer user_data)
 static void
 htmlbar_insert_font_minus_tag(GtkAction * action, gpointer user_data)
 {
-	doc_insert_two_strings(BFWIN(user_data)->current_document,
-						   get_curlang_option_value(BFWIN(user_data), lang_is_XHTML) ? cap("<SPAN STYLE=\"font-size: smaller;\">") : cap("<FONT SIZE=\"-1\">")
-						   , get_curlang_option_value(BFWIN(user_data), lang_is_XHTML) ? cap("</SPAN>") : cap("</FONT>"));
+	doc_insert_two_strings(BFWIN(user_data)->current_document, cap("<SPAN STYLE=\"font-size: smaller;\">"), cap("</SPAN>"));
 }
 
 static void
 htmlbar_insert_font_plus_tag(GtkAction * action, gpointer user_data)
 {
-	doc_insert_two_strings(BFWIN(user_data)->current_document,
-						   get_curlang_option_value(BFWIN(user_data), lang_is_XHTML) ? cap("<SPAN STYLE=\"font-size: larger;\">") : cap("<FONT SIZE=\"+1\">")
-						   , get_curlang_option_value(BFWIN(user_data), lang_is_XHTML) ? cap("</SPAN>") : cap("</FONT>"));
+	doc_insert_two_strings(BFWIN(user_data)->current_document, cap("<SPAN STYLE=\"font-size: larger;\">"), cap("</SPAN>"));
 }
 
 static void
@@ -772,9 +764,7 @@ htmlbar_insert_target_tag(GtkAction * action, gpointer user_data)
 static void
 htmlbar_insert_underline_tag(GtkAction * action, gpointer user_data)
 {
-	doc_insert_two_strings(BFWIN(user_data)->current_document,
-						   get_curlang_option_value(BFWIN(user_data), lang_is_XHTML) ? cap("<SPAN STYLE=\"text-decoration: underline;\">") : cap("<U>")
-						   , get_curlang_option_value(BFWIN(user_data), lang_is_XHTML) ? cap("</SPAN>") : cap("</U>"));
+	doc_insert_two_strings(BFWIN(user_data)->current_document, cap("<SPAN STYLE=\"text-decoration: underline;\">"), cap("</SPAN>"));
 }
 
 static void
@@ -816,14 +806,14 @@ htmlbar_toolbar_show(Thtmlbarwin * hbw, Thtmlbarsession *hbs, gboolean show)
 			GtkWidget *html_notebook;
 			html_notebook = htmlbar_toolbar_create(hbw, hbs);
 #if GTK_CHECK_VERSION(3,2,0)
-			/*gtk_notebook_set_tab_pos(GTK_NOTEBOOK(html_notebook), GTK_POS_TOP); this is the default, so why set it?*/ 
+			/*gtk_notebook_set_tab_pos(GTK_NOTEBOOK(html_notebook), GTK_POS_TOP); this is the default, so why set it?*/
  			gtk_widget_set_hexpand(GTK_WIDGET(html_notebook),TRUE);
  			hbw->handlebox = gtk_event_box_new();
  			gtk_widget_set_name(GTK_WIDGET(hbw->handlebox), "html_notebook_event_box");
-			gtk_container_add(GTK_CONTAINER(hbw->handlebox),html_notebook); 
+			gtk_container_add(GTK_CONTAINER(hbw->handlebox),html_notebook);
 			gtk_container_add(GTK_CONTAINER(hbw->bfwin->toolbarbox),hbw->handlebox);
 			gtk_widget_show_all(hbw->handlebox);
-#else			
+#else
 			hbw->handlebox = gtk_handle_box_new();
 			gtk_container_add(GTK_CONTAINER(hbw->handlebox), html_notebook);
 			gtk_notebook_set_tab_pos(GTK_NOTEBOOK(html_notebook), GTK_POS_TOP);
@@ -1436,8 +1426,8 @@ static GtkWidget *new_html_subtoolbar(Thtmlbarwin * hbw, GtkWidget *html_noteboo
 		g_object_ref(toolbar);
 		gtk_container_remove(GTK_CONTAINER(parent), toolbar);
 	}
-	
-	
+
+
 	gtk_toolbar_set_style(GTK_TOOLBAR(toolbar), GTK_TOOLBAR_ICONS);
 #ifdef MAC_INTEGRATION
 #if GTK_CHECK_VERSION(3,4,0)
@@ -1464,7 +1454,6 @@ htmlbar_toolbar_create(Thtmlbarwin * hbw, Thtmlbarsession *hbs)
 
 	GtkWidget *html_notebook;
 	GtkWidget *toolbar;
-	GtkWidget *menuitem;
 
 	html_notebook = gtk_notebook_new();
 	DEBUG_MSG("htmlbar_toolbar_create, created notebook %p\n",html_notebook);
@@ -1477,14 +1466,14 @@ htmlbar_toolbar_create(Thtmlbarwin * hbw, Thtmlbarsession *hbs)
 	DEBUG_MSG("quickbar done\n");
 	toolbar = new_html_subtoolbar(hbw, html_notebook, gtk_ui_manager_get_widget(bfwin->uimanager, "/HTMLStandardToolbar"), _("Standard"));
 
-	if (main_v->props.allow_dep) {
+	if (main_v->props.format_by_context) {
 		gtk_widget_destroy(gtk_ui_manager_get_widget(bfwin->uimanager, "/HTMLStandardToolbar/FormatStrong"));
 		gtk_widget_destroy(gtk_ui_manager_get_widget(bfwin->uimanager, "/HTMLStandardToolbar/FormatEmphasis"));
 	} else {
 		gtk_widget_destroy(gtk_ui_manager_get_widget(bfwin->uimanager, "/HTMLStandardToolbar/FormatBold"));
 		gtk_widget_destroy(gtk_ui_manager_get_widget(bfwin->uimanager, "/HTMLStandardToolbar/FormatItalic"));
 	}
-	
+
 	DEBUG_MSG("standard created\n");
 	setup_items_for_quickbar(hbw, toolbar);
 	DEBUG_MSG("quickbar setup done\n");
