@@ -5,7 +5,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -14,16 +14,15 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef __IMAGE_H_
 #define __IMAGE_H_
 
-#include "html_diag.h"
+#include "../bluefish.h"
 
-void thumbnail_insert_dialog(Tbfwin *bfwin);
-void multi_thumbnail_dialog(Tbfwin *bfwin);
+void thumbnail_insert_dialog(Tbfwin * bfwin);
+void multi_thumbnail_dialog(Tbfwin * bfwin);
 
-#endif /* __IMAGE_H_ */
+#endif							/* __IMAGE_H_ */
