@@ -1,11 +1,11 @@
 /* Bluefish HTML Editor
  * snippets_wizard.c - plugin for snippets sidebar
  *
- * Copyright (C) 2006,2009 Olivier Sessink
+ * Copyright (C) 2006,2009-2011 Olivier Sessink
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -14,10 +14,9 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-/* #define DEBUG */
+/*#define DEBUG*/
 
 #include <string.h>
 
@@ -117,9 +116,7 @@ static gpointer snippets_build_pageSnr(Tsnipwiz *snwiz, GtkWidget *dialog_action
 
 	const gchar *matchPattern[] = {
 		N_("Normal"),
-		N_("Entire word only"),
-		N_("POSIX"),
-		N_("PERL"),
+		N_("PERL")
 	};
 	GtkWidget *label;
 	gint i;
@@ -130,8 +127,11 @@ static gpointer snippets_build_pageSnr(Tsnipwiz *snwiz, GtkWidget *dialog_action
 	gtk_table_set_col_spacings(GTK_TABLE (p->table), 12);
 	gtk_box_pack_start(GTK_BOX(dialog_action), p->table, TRUE, TRUE, 0);
 	
-	label = gtk_label_new(_("Specify a search and a replace pattern. You may use %0, %1, ...%5 placeholders to ask for values when you activate this item. Give these placeholders an appropriate name on the right."));
+	label = gtk_label_new(_("Specify a search and a replace pattern. You may use %0, %1, ...%5 placeholders to ask for values when you activate this item. Give these placeholders an appropriate name on the right. (Please use %% if you need literal % in your string!)"));
 	/*gtk_label_set_use_markup(GTK_LABEL(label),TRUE);*/
+#if GTK_CHECK_VERSION(3,2,0)
+	gtk_label_set_width_chars(GTK_LABEL(label),50);
+#endif
 	gtk_label_set_line_wrap(GTK_LABEL(label),TRUE);
 	gtk_table_attach(GTK_TABLE(p->table),label, 0,4,0,1
 					,GTK_FILL,GTK_FILL,0,0);
@@ -144,26 +144,26 @@ static gpointer snippets_build_pageSnr(Tsnipwiz *snwiz, GtkWidget *dialog_action
 	dialog_mnemonic_label_in_table(_("Replace _with: "), p->replace, p->table, 0, 1, 2, 3);
 	gtk_table_attach(GTK_TABLE(p->table),p->replace, 1,4,2,3,GTK_FILL|GTK_EXPAND,GTK_FILL,0,0);
 	
-	p->scope = gtk_combo_box_new_text();
+	p->scope = gtk_combo_box_text_new();
 	for (i = 0; i < G_N_ELEMENTS(scope); i++) {
-		gtk_combo_box_append_text(GTK_COMBO_BOX(p->scope), scope[i]);
+		gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(p->scope), _(scope[i]));
 	}
 	dialog_mnemonic_label_in_table(_("Sco_pe: "), p->scope, p->table, 0, 1, 3, 4);
 	gtk_table_attach(GTK_TABLE(p->table),p->scope, 1,2,3,4,GTK_FILL|GTK_EXPAND,GTK_SHRINK,0,0);
 	
-	p->matchtype = gtk_combo_box_new_text();
+	p->matchtype = gtk_combo_box_text_new();
 	for (i = 0; i < G_N_ELEMENTS(matchPattern); i++) {
-		gtk_combo_box_append_text(GTK_COMBO_BOX(p->matchtype), matchPattern[i]);
+		gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(p->matchtype), _(matchPattern[i]));
 	}
 	dialog_mnemonic_label_in_table(_("Match Patter_n: "), p->matchtype, p->table, 0, 1, 4, 5);
 	gtk_table_attach(GTK_TABLE(p->table), p->matchtype, 1, 2, 4, 5, GTK_EXPAND|GTK_FILL,GTK_SHRINK, 0, 0);
 	
 	p->casesens = gtk_check_button_new_with_mnemonic(_("Case sensitive _matching"));
-	gtk_tooltips_set_tip(main_v->tooltips,p->casesens,_("Only match if case (upper/lower) is identical."),NULL);
+	gtk_widget_set_tooltip_text(p->casesens,_("Only match if case (upper/lower) is identical."));
 	gtk_table_attach(GTK_TABLE(p->table), p->casesens, 0, 2, 5, 6, GTK_EXPAND|GTK_FILL,GTK_SHRINK, 0, 0);
 	
 	p->escapechars = gtk_check_button_new_with_mnemonic(_("_Use escape chars"));
-	gtk_tooltips_set_tip(main_v->tooltips,p->escapechars,_("Unescape backslash escaped characters such as \\n, \\t etc."),NULL);
+	gtk_widget_set_tooltip_text(p->escapechars,_("Unescape backslash escaped characters such as \\n, \\t etc."));
 	gtk_table_attach(GTK_TABLE(p->table), p->escapechars, 0, 2, 6, 7, GTK_EXPAND|GTK_FILL,GTK_SHRINK, 0, 0);
 	
 	for (i = 0; i <  6; i++) {
@@ -193,10 +193,12 @@ static gpointer snippets_build_pageSnr(Tsnipwiz *snwiz, GtkWidget *dialog_action
 				i++;
 			} else if (xmlStrEqual(cur->name, (const xmlChar *)"searchpat")) {
 				tmpstr = xmlNodeListGetString(snippets_v.doc, cur->xmlChildrenNode, 1);
+				DEBUG_MSG("searchpattern: %s\n",tmpstr);
 				gtk_entry_set_text(GTK_ENTRY(p->searchpat),(gchar *)tmpstr);
 				g_free(tmpstr);
 			} else if (xmlStrEqual(cur->name, (const xmlChar *)"replacepat")) {
 				tmpstr = xmlNodeListGetString(snippets_v.doc, cur->xmlChildrenNode, 1);
+				DEBUG_MSG("replacepattern: %s\n",tmpstr);
 				gtk_entry_set_text(GTK_ENTRY(p->replace),(gchar *)tmpstr);
 				g_free(tmpstr);
 			}
@@ -256,7 +258,7 @@ static gint snippets_test_pageSnr(Tsnipwiz *snwiz, gpointer data) {
 	
 	/* build the leaf */
 	xmlSetProp(childn, (const xmlChar *)"title", (const xmlChar *)snwiz->name);
-	if (strlen(snwiz->description)) {
+	if (snwiz->description) {
 		xmlSetProp(childn, (const xmlChar *)"tooltip", (const xmlChar *)snwiz->description);
 	}
 	
@@ -280,12 +282,6 @@ static gint snippets_test_pageSnr(Tsnipwiz *snwiz, gpointer data) {
 			tmp = "normal";
 		break;
 		case 1:
-			tmp = "word";
-		break;
-		case 2:
-			tmp = "posix";
-		break;
-		case 3:
 			tmp = "perl";
 		break;
 	}
@@ -296,8 +292,8 @@ static gint snippets_test_pageSnr(Tsnipwiz *snwiz, gpointer data) {
 	
 	search = gtk_editable_get_chars(GTK_EDITABLE(p->searchpat),0,-1);
 	replace = gtk_editable_get_chars(GTK_EDITABLE(p->replace),0,-1);
-	xmlNewChild(childn,NULL,(const xmlChar *)"searchpat",(const xmlChar *)search);
-	xmlNewChild(childn,NULL,(const xmlChar *)"replacepat",(const xmlChar *)replace);
+	xmlNewTextChild(childn,NULL,(const xmlChar *)"searchpat",(const xmlChar *)search);
+	xmlNewTextChild(childn,NULL,(const xmlChar *)"replacepat",(const xmlChar *)replace);
 	for (i = 0; i <  6; i++) {
 		gchar *tmpstr;
 		tmpstr = gtk_editable_get_chars(GTK_EDITABLE(p->entries[i]),0,-1);
@@ -336,11 +332,14 @@ static gpointer snippets_build_pageInsert(Tsnipwiz *snwiz, GtkWidget *dialog_act
 	gtk_table_set_col_spacings(GTK_TABLE (p2->table), 12);
 	gtk_box_pack_start(GTK_BOX(dialog_action), p2->table, TRUE, TRUE, 0);
 	
-	label = gtk_label_new(_("The <i>before</i> text will be inserted before the cursor position or the current selection, the <i>after</i> text will be inserted after the cursor position or the current selection. You may use %0, %1, ...%9 placeholders to ask for values when you activate this item. Give these placeholders an appropriate name on the right."));
+	label = gtk_label_new(_("The <i>before</i> text will be inserted before the cursor position or the current selection, the <i>after</i> text will be inserted after the cursor position or the current selection. You may use %0, %1, ...%9 placeholders to ask for values when you activate this item. Give these placeholders an appropriate name on the right. (Please use %% if you need literal % in your string!)"));
 	gtk_label_set_use_markup(GTK_LABEL(label),TRUE);
 	gtk_label_set_line_wrap(GTK_LABEL(label),TRUE);
-	gtk_table_attach(GTK_TABLE(p2->table),label, 0,3,0,1
-					,GTK_FILL,GTK_FILL,0,0);
+#if GTK_CHECK_VERSION(3,2,0)
+	gtk_label_set_width_chars(GTK_LABEL(label),50);
+#endif
+	gtk_table_attach(GTK_TABLE(p2->table),label, 0,5,0,1
+					,GTK_FILL|GTK_EXPAND,GTK_FILL,0,0);
 	
 	label = gtk_label_new(_("<i>Before</i> text"));
 	gtk_label_set_use_markup(GTK_LABEL(label),TRUE);
@@ -376,7 +375,7 @@ static gpointer snippets_build_pageInsert(Tsnipwiz *snwiz, GtkWidget *dialog_act
 		p2->entries[i] = gtk_entry_new();
 		gtk_table_attach(GTK_TABLE(p2->table),p2->entries[i], 2,3,i+2,i+3
 					,GTK_FILL,GTK_FILL,0,0);
-		p2->is_file[i] = gtk_toggle_button_new();
+		p2->is_file[i] = gtk_check_button_new();
 		gtk_table_attach(GTK_TABLE(p2->table),p2->is_file[i], 3,4,i+2,i+3
 					,GTK_SHRINK,GTK_SHRINK,0,0);
 	}
@@ -450,7 +449,7 @@ static gint snippets_test_pageInsert(Tsnipwiz *snwiz, gpointer data) {
 	before = textbuffer_get_all_chars(p2->before);	
 	after = textbuffer_get_all_chars(p2->after);		
 	xmlSetProp(childn, (const xmlChar *)"title", (const xmlChar *)snwiz->name);
-	if (strlen(snwiz->description)) {
+	if (snwiz->description) {
 		xmlSetProp(childn, (const xmlChar *)"tooltip", (const xmlChar *)snwiz->description);
 	}
 	
@@ -462,7 +461,7 @@ static gint snippets_test_pageInsert(Tsnipwiz *snwiz, gpointer data) {
 		if (strlen(tmpstr)>0) {
 			tmpn = xmlNewChild(childn,NULL,(const xmlChar *)"param", NULL);
 			xmlSetProp(tmpn, (const xmlChar *)"name", (const xmlChar *)tmpstr);
-			if (GTK_TOGGLE_BUTTON(p2->is_file[i])->active) {
+			if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(p2->is_file[i]))) {
 				xmlSetProp(tmpn, (const xmlChar *)"is_file", (const xmlChar *)"1");
 			}
 		}
@@ -714,21 +713,22 @@ static void snipwiz_dialog_response_lcb(GtkDialog *dialog, gint response, Tsnipw
 		break;
 	}
 	if (snwiz->pagenum != newpagenum) {
+		GtkWidget *vbox = gtk_dialog_get_content_area(GTK_DIALOG(snwiz->dialog));
 		switch (newpagenum) { /* build a new page */
 			case page_type:
-				snwiz->pagestruct = snippets_build_pageType(snwiz,GTK_DIALOG(snwiz->dialog)->vbox);
+				snwiz->pagestruct = snippets_build_pageType(snwiz, vbox);
 			break;
 			case page_name:
-				snwiz->pagestruct = snippets_build_pageName(snwiz,GTK_DIALOG(snwiz->dialog)->vbox);
+				snwiz->pagestruct = snippets_build_pageName(snwiz, vbox);
 			break;
 			case page_branch:
-				snwiz->pagestruct = snippets_build_pageBranch(snwiz,GTK_DIALOG(snwiz->dialog)->vbox);
+				snwiz->pagestruct = snippets_build_pageBranch(snwiz, vbox);
 			break;
 			case page_insert:
-				snwiz->pagestruct = snippets_build_pageInsert(snwiz,GTK_DIALOG(snwiz->dialog)->vbox);
+				snwiz->pagestruct = snippets_build_pageInsert(snwiz, vbox);
 			break;
 			case page_snr:
-				snwiz->pagestruct = snippets_build_pageSnr(snwiz,GTK_DIALOG(snwiz->dialog)->vbox);
+				snwiz->pagestruct = snippets_build_pageSnr(snwiz, vbox);
 			break;
 			case page_finished:
 				gtk_widget_destroy(snwiz->dialog);
@@ -746,17 +746,19 @@ static void snipwiz_dialog_response_lcb(GtkDialog *dialog, gint response, Tsnipw
 
 void snippets_new_item_dialog(Tsnippetswin *snw, xmlNodePtr node) {
 	Tsnipwiz *snwiz;
+	GtkWidget *vbox;
 	
 	snwiz = g_new0(Tsnipwiz,1);
 	snwiz->snw = snw;
 	snwiz->node = node;
-	snwiz->dialog = gtk_dialog_new_with_buttons(_("New snippet"),GTK_WINDOW(snw->bfwin->main_window),
+	snwiz->dialog = gtk_dialog_new_with_buttons(node? _("Edit snippet") :_("New snippet"),GTK_WINDOW(snw->bfwin->main_window),
 					GTK_DIALOG_DESTROY_WITH_PARENT,
 					GTK_STOCK_CANCEL,GTK_RESPONSE_REJECT,
 					GTK_STOCK_GO_FORWARD,1,
 					NULL);
 	gtk_window_set_default_size(GTK_WINDOW(snwiz->dialog),500,400);
 	g_signal_connect(G_OBJECT(snwiz->dialog), "response", G_CALLBACK(snipwiz_dialog_response_lcb), snwiz);
+	vbox = gtk_dialog_get_content_area(GTK_DIALOG(snwiz->dialog));
 	if (node) {
 		if (xmlStrEqual(snw->lastclickednode->name, (const xmlChar *)"leaf")) {
 			xmlChar *type = xmlGetProp(node, (const xmlChar *)"type");
@@ -765,18 +767,18 @@ void snippets_new_item_dialog(Tsnippetswin *snw, xmlNodePtr node) {
 			} else if (xmlStrEqual(type, (const xmlChar *)"snr")) {
 				snwiz->choice = 2;
 			} 
-			snwiz->pagestruct = snippets_build_pageName(snwiz,GTK_DIALOG(snwiz->dialog)->vbox);
+			snwiz->pagestruct = snippets_build_pageName(snwiz, vbox);
 			snwiz->pagenum = page_name;
 		} else {
-			snwiz->pagestruct = snippets_build_pageBranch(snwiz,GTK_DIALOG(snwiz->dialog)->vbox);
+			snwiz->pagestruct = snippets_build_pageBranch(snwiz, vbox);
 			snwiz->pagenum = page_branch;
 		}
 	} else {
 		if (!snw->lastclickednode) {
-			snwiz->pagestruct = snippets_build_pageBranch(snwiz,GTK_DIALOG(snwiz->dialog)->vbox);
+			snwiz->pagestruct = snippets_build_pageBranch(snwiz, vbox);
 			snwiz->pagenum = page_branch;
 		} else {
-			snwiz->pagestruct = snippets_build_pageType(snwiz,GTK_DIALOG(snwiz->dialog)->vbox);
+			snwiz->pagestruct = snippets_build_pageType(snwiz, vbox);
 			snwiz->pagenum = page_type;
 		}
 	}
