@@ -97,12 +97,14 @@ static void
 apply_syntax(Tbluefishprint *bfprint, PangoLayout *layout, Tpage *page_s, Tpage *page_e)
 {
 	PangoAttrList *alist;
-	GList *tmplist;
+	GList *tmplist=NULL;
 	GtkTextIter iter;
 	
 	alist = pango_attr_list_new();
 	
-	tmplist = g_list_first(BLUEFISH_TEXT_VIEW(bfprint->doc->view)->bflang->tags);
+	if (BLUEFISH_TEXT_VIEW(bfprint->doc->view)->bflang) {
+		tmplist = g_list_first(BLUEFISH_TEXT_VIEW(bfprint->doc->view)->bflang->tags);
+	}
 	while (tmplist) {
 		GtkTextTag *tag = tmplist->data;
 		gboolean donewithtag = FALSE;
@@ -401,7 +403,7 @@ doc_print(Tdocument *doc)
 	if(res == GTK_PRINT_OPERATION_RESULT_APPLY) {
 		if(printsettings != NULL)
 			g_object_unref(printsettings);
-			printsettings = g_object_ref(gtk_print_operation_get_print_settings(print));
+		printsettings = g_object_ref(gtk_print_operation_get_print_settings(print));
 	}
 	if (printsettings != NULL)
 		g_object_unref(printsettings);
