@@ -66,6 +66,7 @@ free_session(Tsessionvars * session)
 	free_stringlist(session->recent_files);
 	free_stringlist(session->recent_dirs);
 	g_free(session->snr3_filepattern);
+	g_free(session->snr3_basedir);
 	g_free(session->ssearch_text);
 	g_free(session->opendir);
 	g_free(session->savedir);
@@ -99,6 +100,8 @@ project_setup_initial_session(Tsessionvars * session, gboolean before_parse)
 		session->last_filefilter = g_strdup(main_v->session->last_filefilter);
 		session->default_mime_type = g_strdup(main_v->session->default_mime_type);
 		session->template = g_strdup(main_v->session->template);
+		session->snr3_basedir = g_strdup(main_v->session->snr3_basedir);
+		session->snr3_filepattern = g_strdup(main_v->session->snr3_filepattern);
 #ifdef HAVE_LIBENCHANT
 		session->spell_lang = g_strdup(main_v->session->spell_lang);
 		session->spell_check_default = main_v->session->spell_check_default;
@@ -393,9 +396,9 @@ project_open_from_file(Tbfwin * bfwin, GFile * fromuri)
 	main_v->globses.recent_projects =
 				add_to_history_stringlist(main_v->globses.recent_projects, curi, TRUE);
 	if (main_v->props.recent_means_recently_closed) {
-		bfwin_recent_menu_remove(bfwin, TRUE, curi);
+		bfwin_recent_menu_remove(bfwin, TRUE, curi, fromuri);
 	} else {
-		bfwin_recent_menu_add(bfwin,TRUE, curi);
+		bfwin_recent_menu_add(bfwin,TRUE, curi, fromuri);
 	}
 	if (main_v->props.register_recent_mode != 0) {
 		gtk_recent_manager_add_item(main_v->recentm, curi);
@@ -502,7 +505,7 @@ project_save_and_mark_closed(Tbfwin * bfwin)
 
 		if (bfwin->project->uri && main_v->props.recent_means_recently_closed) { /* Add menu entry only if we use "recently_closed" logic otherwise it is already there*/
 			gchar *curi = g_file_get_uri(bfwin->project->uri);
-			bfwin_recent_menu_add(bfwin, TRUE, curi);
+			bfwin_recent_menu_add(bfwin, TRUE, curi, bfwin->project->uri);
 			g_free(curi);
 		}
 
@@ -515,8 +518,6 @@ project_final_close(Tbfwin * bfwin, gboolean close_win)
 {
 	if (!bfwin->project)
 		return TRUE;
-/*	if (!close_win)
-		bfwin_recent_menu_add(bfwin, bfwin->project->uri, NULL, TRUE);*/
 
 	project_destroy(bfwin->project);
 	/* we should only set the window for nonproject if the window will keep alive */
