@@ -46,7 +46,7 @@ GList *duplicate_arraylist(GList *arraylist);
 GList *remove_from_stringlist(GList *which_list, const gchar * string);
 GList *limit_stringlist(GList *which_list, gint num_entries, gboolean keep_end);
 GList *find_in_stringlist(GList *thelist, const gchar *string);
-GList *add_to_history_stringlist(GList *which_list, const gchar *string, gboolean recent_on_top, gboolean move_if_exists);
+GList *add_to_history_stringlist(GList *which_list, const gchar *string, gboolean move_if_exists);
 /* adds a string to a stringlist if it is not yet in there */
 GList *add_to_stringlist(GList * which_list, const gchar * string);
 gchar *stringlist_to_string(GList *stringlist, gchar *delimiter);
